using System;
using System.EnterpriseServices;
using System.Security.Principal;
using System.Runtime.InteropServices;
using DataProtection;

namespace DPAPIComp
{
	public interface IDataProtectorInterface
	{
		byte[] Encrypt(byte[] plainText);
		byte[] Decrypt(byte[] cipherText);
	}


	/// <summary>
	/// Summary description for DataProtectorComp.
	/// </summary>
	[ComponentAccessControl]
	[SecureMethod]
	public class DataProtectorComp : ServicedComponent, IDataProtectorInterface
	{
		public DataProtectorComp()
		{
		}

		[SecurityRole("Encryptor")]
		public byte[] Encrypt(byte[] plainText)
		{
			DataProtector dp = new DataProtector( DataProtector.Store.USE_USER_STORE );
			byte[] cipherText = null;
			try
			{
				cipherText = dp.Encrypt(plainText, null);
			}
			catch(Exception ex)
			{
				throw new Exception("Exception encrypting. " + ex.Message);
			}
			return cipherText;
		}

		[SecurityRole("Decryptor")]
		public byte[] Decrypt(byte[] cipherText)
		{
			DataProtector dp = new DataProtector( DataProtector.Store.USE_USER_STORE );
			byte[] plainText = null;

			try
			{
				plainText = dp.Decrypt(cipherText,null);
			}
			catch(Exception ex)
			{
				throw new Exception("Exception decrypting. " + ex.Message);
			}
			return plainText;
		}
	}
}
